@@ -1,5 +1,6 @@
 #![allow(missing_docs, trivial_casts, unused_variables, unused_mut, unused_imports, unused_extern_crates, non_camel_case_types)]
 
+use chrono::NaiveDate;
 use async_trait::async_trait;
 use futures::Stream;
 use std::error::Error;
@@ -10,7 +11,7 @@ use serde::{Serialize, Deserialize};
 type ServiceError = Box<dyn Error + Send + Sync + 'static>;
 
 pub const BASE_PATH: &'static str = "";
-pub const API_VERSION: &'static str = "0.5.0";
+pub const API_VERSION: &'static str = "0.6.0";
 
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 #[must_use]
@@ -120,7 +121,7 @@ pub trait Api<C: Send + Sync> {
         email: Option<String>,
         phone: Option<String>,
         undergraduate_school: Option<String>,
-        date_of_birth: Option<chrono::DateTime::<chrono::Utc>>,
+        date_of_birth: Option<NaiveDate>,
         place_of_birth: Option<String>,
         polity_name: Option<String>,
         specialism: Option<String>,
@@ -171,7 +172,7 @@ pub trait ApiNoContext<C: Send + Sync> {
         email: Option<String>,
         phone: Option<String>,
         undergraduate_school: Option<String>,
-        date_of_birth: Option<chrono::DateTime::<chrono::Utc>>,
+        date_of_birth: Option<NaiveDate>,
         place_of_birth: Option<String>,
         polity_name: Option<String>,
         specialism: Option<String>,
@@ -253,7 +254,7 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
         email: Option<String>,
         phone: Option<String>,
         undergraduate_school: Option<String>,
-        date_of_birth: Option<chrono::DateTime::<chrono::Utc>>,
+        date_of_birth: Option<NaiveDate>,
         place_of_birth: Option<String>,
         polity_name: Option<String>,
         specialism: Option<String>,
