@@ -1,9 +1,58 @@
 #![allow(unused_qualifications)]
 
+use std::str::FromStr;
+use chrono::NaiveDate;
 use crate::models;
 #[cfg(any(feature = "client", feature = "server"))]
 use crate::header;
 
+/// Enumeration of values.
+/// Since this enum's variants do not hold data, we can easily define them them as `#[repr(C)]`
+/// which helps with FFI.
+#[allow(non_camel_case_types)]
+#[repr(C)]
+#[derive(Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord, serde::Serialize, serde::Deserialize)]
+#[cfg_attr(feature = "conversion", derive(frunk_enum_derive::LabelledGenericEnum))]
+pub enum EducationalStage {
+    #[serde(rename = "ELEMENTARY_SCHOOL")]
+    ELEMENTARY_SCHOOL,
+    #[serde(rename = "MIDDLE_SCHOOL")]
+    MIDDLE_SCHOOL,
+    #[serde(rename = "HIGH_SCHOOL")]
+    HIGH_SCHOOL,
+    #[serde(rename = "BACHELOR")]
+    BACHELOR,
+    #[serde(rename = "MASTER")]
+    MASTER,
+}
+
+impl std::fmt::Display for EducationalStage {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        match *self {
+            EducationalStage::ELEMENTARY_SCHOOL => write!(f, "{}", "ELEMENTARY_SCHOOL"),
+            EducationalStage::MIDDLE_SCHOOL => write!(f, "{}", "MIDDLE_SCHOOL"),
+            EducationalStage::HIGH_SCHOOL => write!(f, "{}", "HIGH_SCHOOL"),
+            EducationalStage::BACHELOR => write!(f, "{}", "BACHELOR"),
+            EducationalStage::MASTER => write!(f, "{}", "MASTER"),
+        }
+    }
+}
+
+impl std::str::FromStr for EducationalStage {
+    type Err = String;
+
+    fn from_str(s: &str) -> std::result::Result<Self, Self::Err> {
+        match s {
+            "ELEMENTARY_SCHOOL" => std::result::Result::Ok(EducationalStage::ELEMENTARY_SCHOOL),
+            "MIDDLE_SCHOOL" => std::result::Result::Ok(EducationalStage::MIDDLE_SCHOOL),
+            "HIGH_SCHOOL" => std::result::Result::Ok(EducationalStage::HIGH_SCHOOL),
+            "BACHELOR" => std::result::Result::Ok(EducationalStage::BACHELOR),
+            "MASTER" => std::result::Result::Ok(EducationalStage::MASTER),
+            _ => std::result::Result::Err(format!("Value not valid: {}", s)),
+        }
+    }
+}
+
 /// Enumeration of values.
 /// Since this enum's variants do not hold data, we can easily define them them as `#[repr(C)]`
 /// which helps with FFI.
@@ -142,7 +191,7 @@ pub struct StudentUpsert {
     /// date of birth in format YYYY-MM-DD
     #[serde(rename = "dateOfBirth")]
     #[serde(skip_serializing_if="Option::is_none")]
-    pub date_of_birth: Option<chrono::DateTime::<chrono::Utc>>,
+    pub date_of_birth: Option<NaiveDate>,
 
     #[serde(rename = "placeOfBirth")]
     #[serde(skip_serializing_if="Option::is_none")]
@@ -160,6 +209,26 @@ pub struct StudentUpsert {
     #[serde(skip_serializing_if="Option::is_none")]
     pub undergraduate_school: Option<String>,
 
+    #[serde(rename = "nationality")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub nationality: Option<String>,
+
+    #[serde(rename = "EducationalStage")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub educational_stage: Option<models::EducationalStage>,
+
+    #[serde(rename = "race")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub race: Option<String>,
+
+    #[serde(rename = "programId")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub program_id: Option<uuid::Uuid>,
+
+    #[serde(rename = "isMale")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub is_male: Option<bool>,
+
 }
 
 impl StudentUpsert {
@@ -176,6 +245,11 @@ impl StudentUpsert {
             email: None,
             phone: None,
             undergraduate_school: None,
+            nationality: Some("Vietnamese".to_string()),
+            educational_stage: None,
+            race: None,
+            program_id: None,
+            is_male: Some(true),
         }
     }
 }
@@ -236,6 +310,28 @@ impl std::string::ToString for StudentUpsert {
             params.push(undergraduate_school.to_string());
         }
 
+
+        if let Some(ref nationality) = self.nationality {
+            params.push("nationality".to_string());
+            params.push(nationality.to_string());
+        }
+
+        // Skipping EducationalStage in query parameter serialization
+
+
+        if let Some(ref race) = self.race {
+            params.push("race".to_string());
+            params.push(race.to_string());
+        }
+
+        // Skipping programId in query parameter serialization
+
+
+        if let Some(ref is_male) = self.is_male {
+            params.push("isMale".to_string());
+            params.push(is_male.to_string());
+        }
+
         params.join(",").to_string()
     }
 }
@@ -256,11 +352,16 @@ impl std::str::FromStr for StudentUpsert {
             pub first_name: Vec<String>,
             pub middle_name: Vec<String>,
             pub last_name: Vec<String>,
-            pub date_of_birth: Vec<chrono::DateTime::<chrono::Utc>>,
+            pub date_of_birth: Vec<NaiveDate>,
             pub place_of_birth: Vec<String>,
             pub email: Vec<String>,
             pub phone: Vec<String>,
             pub undergraduate_school: Vec<String>,
+            pub nationality: Vec<String>,
+            pub educational_stage: Vec<models::EducationalStage>,
+            pub race: Vec<String>,
+            pub program_id: Vec<uuid::Uuid>,
+            pub is_male: Vec<bool>,
         }
 
         let mut intermediate_rep = IntermediateRep::default();
@@ -283,11 +384,16 @@ impl std::str::FromStr for StudentUpsert {
                     "firstName" => intermediate_rep.first_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "middleName" => intermediate_rep.middle_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "lastName" => intermediate_rep.last_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "dateOfBirth" => intermediate_rep.date_of_birth.push(<chrono::DateTime::<chrono::Utc> as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "dateOfBirth" => intermediate_rep.date_of_birth.push(<NaiveDate as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "placeOfBirth" => intermediate_rep.place_of_birth.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "email" => intermediate_rep.email.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "phone" => intermediate_rep.phone.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "undergraduateSchool" => intermediate_rep.undergraduate_school.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "nationality" => intermediate_rep.nationality.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "EducationalStage" => intermediate_rep.educational_stage.push(<models::EducationalStage as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "race" => intermediate_rep.race.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "programId" => intermediate_rep.program_id.push(<uuid::Uuid as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "isMale" => intermediate_rep.is_male.push(<bool as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     _ => return std::result::Result::Err("Unexpected key while parsing StudentUpsert".to_string())
                 }
             }
@@ -309,6 +415,11 @@ impl std::str::FromStr for StudentUpsert {
             email: intermediate_rep.email.into_iter().next(),
             phone: intermediate_rep.phone.into_iter().next(),
             undergraduate_school: intermediate_rep.undergraduate_school.into_iter().next(),
+            nationality: intermediate_rep.nationality.into_iter().next(),
+            educational_stage: intermediate_rep.educational_stage.into_iter().next(),
+            race: intermediate_rep.race.into_iter().next(),
+            program_id: intermediate_rep.program_id.into_iter().next(),
+            is_male: intermediate_rep.is_male.into_iter().next(),
         })
     }
 }
@@ -391,7 +502,7 @@ pub struct StudentView {
     /// date of birth in format YYYY-MM-DD
     #[serde(rename = "dateOfBirth")]
     #[serde(skip_serializing_if="Option::is_none")]
-    pub date_of_birth: Option<chrono::DateTime::<chrono::Utc>>,
+    pub date_of_birth: Option<NaiveDate>,
 
     #[serde(rename = "placeOfBirth")]
     #[serde(skip_serializing_if="Option::is_none")]
@@ -525,7 +636,7 @@ impl std::str::FromStr for StudentView {
             pub christian_name: Vec<String>,
             pub title: Vec<models::StudentTitle>,
             pub name: Vec<String>,
-            pub date_of_birth: Vec<chrono::DateTime::<chrono::Utc>>,
+            pub date_of_birth: Vec<NaiveDate>,
             pub place_of_birth: Vec<String>,
             pub email: Vec<String>,
             pub phone: Vec<String>,
@@ -554,7 +665,7 @@ impl std::str::FromStr for StudentView {
                     "christianName" => intermediate_rep.christian_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "title" => intermediate_rep.title.push(<models::StudentTitle as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "name" => intermediate_rep.name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "dateOfBirth" => intermediate_rep.date_of_birth.push(<chrono::DateTime::<chrono::Utc> as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "dateOfBirth" => intermediate_rep.date_of_birth.push(<NaiveDate as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "placeOfBirth" => intermediate_rep.place_of_birth.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "email" => intermediate_rep.email.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "phone" => intermediate_rep.phone.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
